@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Local Outlier Factor (LOF). Implemented on scikit-learn library.
 """
-# Author: Yue Zhao <yuezhao@cs.toronto.edu>
+# Author: Yue Zhao <zhaoy@cmu.edu>
 # License: BSD 2 clause
 
 from __future__ import division
@@ -14,7 +14,7 @@ from sklearn.utils.validation import check_array
 from .base import BaseDetector
 from ..utils.utility import invert_order
 # noinspection PyProtectedMember
-from ..utils.utility import _sklearn_version_20
+from ..utils.utility import _get_sklearn_version
 
 
 class LOF(BaseDetector):
@@ -143,15 +143,20 @@ class LOF(BaseDetector):
 
     # noinspection PyIncorrectDocstring
     def fit(self, X, y=None):
-        """Fit detector. y is optional for unsupervised methods.
+        """Fit detector. y is ignored in unsupervised methods.
 
         Parameters
         ----------
         X : numpy array of shape (n_samples, n_features)
             The input samples.
 
-        y : numpy array of shape (n_samples,), optional (default=None)
-            The ground truth of the input samples (labels).
+        y : Ignored
+            Not used, present for API consistency by convention.
+
+        Returns
+        -------
+        self : object
+            Fitted estimator.
         """
         # validate inputs X and y (optional)
         X = check_array(X)
@@ -196,7 +201,7 @@ class LOF(BaseDetector):
 
         # Invert outlier scores. Outliers comes with higher outlier scores
         # noinspection PyProtectedMember
-        if _sklearn_version_20():
+        if _get_sklearn_version() > 19:
             return invert_order(self.detector_._score_samples(X))
         else:
             return invert_order(self.detector_._decision_function(X))
